@@ -62,7 +62,7 @@ type addService struct {
 func (as addService) isSupervisorMessage() {}
 
 type stopSupervisor struct {
-	done chan struct{}
+	done chan UnstoppedServiceReport
 }
 
 func (ss stopSupervisor) isSupervisorMessage() {}
@@ -71,12 +71,6 @@ func (s *Supervisor) panic() {
 	s.control <- panicSupervisor{}
 }
 
-type serviceTerminated struct {
-	id serviceID
-}
-
-func (st serviceTerminated) isSupervisorMessage() {}
-
 type panicSupervisor struct {
 }
 
